==> nextcloud-14.0.4.tar.bz2: nextcloud/apps/gallery/l10n/mn.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Зургийн цомог",
    "There was a problem reading files from this album" : "Энэ цомогоос файл уншихад алдаа гарлаа",
    "Aborting preview. Could not find the file" : "Урьдилан харах үйлдлийг цуцлав. Файл олдсонгүй",
    "Could not move \"{file}\", target exists" : "\"{file}\"-г зөөж чадсангүй, файлын нэр давхцаж байна",
    "Could not move \"{file}\"" : "\"{file}\"-г зөөж чадсангүй",
    "No compatible server found at {remote}" : "{remote}-д холбогдох боломжтой сервер олдсонгүй",
    "Invalid server url" : "Серверийн url буруу байна",
    "Could not load the description" : "Тайлбарыг ачаалж чадсангүй",
    "Could not load the description: " : "Тайлбарыг ачаалж чадсангүй:",
    "Copyright" : "Зохиогчийн эрх",
    "Could not load the copyright notice: " : "Зохиогчийн эрхийн анхааруулга ачаалж чадсангүй:",
    "Copyright notice" : "Зохиогчийн эрхийн анхааруулга",
    "Link to copyright document" : "Зохиогчийн эрхийн документын холбоос",
    "This application may not work properly on your browser." : "Таны browser дээр энэ программ зөв ажиллахгүй байж магадгүй.",
    "Your browser is not supported!" : "Таны browser-г дэмжихгүй!",
    "Album cannot be shown" : "Зургийн цомогийг харуулж чадахгүй",
    "No media files found" : "Медиа файлууд олдсонгүй",
    "Configuration error" : "Тохиргооны алдаа",
    "Hide Album" : "Зургийн цомогийг нуух",
    "Next" : "Даараах",
    "Play" : "Тоглуулах",
    "Pause" : "Түр зогсоох",
    "Previous" : "Өмнөх",
    "Close" : "Хаах",
    "Download" : "Татаж авах",
    "Delete" : "Устгах",
    "Share" : "Түгээх",
    "File name cannot be empty." : "Файлын нэр хоосон байж болохгүй",
    "Upload" : "Байршуулах",
    "Error" : "Алдаа",
    "Error while sharing" : "Түгээхэд алдаа гарлаа",
    "Link" : "Холбоос",
    "Password protect" : "Нууц үгээр хамгаалах",
    "Password" : "Нууц үг",
    "Send" : "Илгээх",
    "group" : "бүлэг",
    "remote" : "алсын",
    "notify by email" : "цахим шуудангаар мэдэгдэх",
    "access control" : "хандах эрхийн удирдлага",
    "create" : "үүсгэх",
    "change" : "Өөрчлөх",
    "delete" : "устгах",
    "Password protected" : "Нууц үгээх хамгаалагдсан",
    "Gallery view" : "Зургийн цомог харах",
    "New" : "Шинэ"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.9.tar.bz2: nextcloud/apps/gallery/l10n/mn.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Зургийн цомог",
    "There was a problem reading files from this album" : "Энэ цомогоос файл уншихад алдаа гарлаа",
    "Aborting preview. Could not find the file" : "Урьдилан харах үйлдлийг цуцлав. Файл олдсонгүй",
    "Could not move \"{file}\", target exists" : "\"{file}\"-г зөөж чадсангүй, файлын нэр давхцаж байна",
    "Could not move \"{file}\"" : "\"{file}\"-г зөөж чадсангүй",
    "No compatible server found at {remote}" : "{remote}-д холбогдох боломжтой сервер олдсонгүй",
    "Invalid server url" : "Серверийн url буруу байна",
    "Could not load the description" : "Тайлбарыг ачаалж чадсангүй",
    "Could not load the description: " : "Тайлбарыг ачаалж чадсангүй:",
    "Copyright" : "Зохиогчийн эрх",
    "Could not load the copyright notice: " : "Зохиогчийн эрхийн анхааруулга ачаалж чадсангүй:",
    "Copyright notice" : "Зохиогчийн эрхийн анхааруулга",
    "Link to copyright document" : "Зохиогчийн эрхийн документын холбоос",
    "This application may not work properly on your browser." : "Таны browser дээр энэ программ зөв ажиллахгүй байж магадгүй.",
    "Your browser is not supported!" : "Таны browser-г дэмжихгүй!",
    "Album cannot be shown" : "Зургийн цомогийг харуулж чадахгүй",
    "No media files found" : "Медиа файлууд олдсонгүй",
    "Configuration error" : "Тохиргооны алдаа",
    "Hide Album" : "Зургийн цомогийг нуух",
    "Next" : "Даараах",
    "Play" : "Тоглуулах",
    "Pause" : "Түр зогсоох",
    "Previous" : "Өмнөх",
    "Close" : "Хаах",
    "Download" : "Татаж авах",
    "Delete" : "Устгах",
    "Share" : "Түгээх",
    "Could not create file \"{file}\" because it already exists" : "Ийм нэртэй файл байгаа учир \"{file}\"-г үүсгэж чадахгүй",
    "Could not create file \"{file}\"" : "\"{file}\" файлыг үүсгэж чадсангүй",
    "\"{name}\" is an invalid file name." : "\"{name}\" нь хүчин төгөлдөр бус файлын нэр",
    "File name cannot be empty." : "Файлын нэр хоосон байж болохгүй",
    "Upload" : "Байршуулах",
    "Error" : "Алдаа",
    "Error while sharing" : "Түгээхэд алдаа гарлаа",
    "Share link" : "Холбоос хуваалцах",
    "Link" : "Холбоос",
    "Password protect" : "Нууц үгээр хамгаалах",
    "Password" : "Нууц үг",
    "Allow editing" : "Засварлахыг зөвшөөрөх",
    "Email link to person" : "Холбоосыг цахим шуудангаар илгээх",
    "Send" : "Илгээх",
    "group" : "бүлэг",
    "remote" : "алсын",
    "Resharing is not allowed" : "Дахин хуваалцах зөвшөөрөгдөөгүй",
    "Unshare" : "Түгээлтийг зогсоох",
    "notify by email" : "цахим шуудангаар мэдэгдэх",
    "can edit" : "засаж чадна",
    "access control" : "хандах эрхийн удирдлага",
    "create" : "үүсгэх",
    "change" : "Өөрчлөх",
    "delete" : "устгах",
    "Password protected" : "Нууц үгээх хамгаалагдсан",
    "Sending…" : "Илгээх...",
    "Warning" : "Warning",
    "Sort by name" : "Order by name",
    "Sort by date" : "Order by date"
},
"nplurals=2; plural=(n != 1);");
